@@ -397,7 +397,7 @@ public slots:
 	void toggleFullScreen(const bool fullscreen);
 	int syncFromSource(const QString& sourceFile, int lineNo, bool activatePreview); //lineNo 0 based
 	void syncFromView(const QString& pdfFile, const QFileInfo& masterFile, int page);
-	void loadFile(const QString &fileName, const QFileInfo& masterFile, bool alert = true);
+	void loadFile(const QString &fileName, const QFileInfo& masterFile, bool alert = true, bool focus = true);
 	void printPDF();
 	void setAutoHideToolbars(bool enabled);
 	void hideToolbars();
@@ -422,7 +422,7 @@ private slots:
 	void setGrid();
 
 public slots:
-	void closeSomething();
+	bool closeSomething();
 private slots:
 	void tileWindows();
 	void stackWindows();
@@ -436,6 +436,7 @@ private slots:
 public:
 	void search(const QString& searchText, bool backward, bool incremental, bool caseSensitive, bool sync);
 	void search();
+	static QString debugSyncTeX(const QString& filename);
 private slots:
 	void gotoAnnotation(const PDFAnnotation *ann);
 
