@@ -75,10 +75,11 @@ void CommandInfo::setCommandLine(const QString& cmdString){
 		                   && (!unquote.contains(" ") || (!unquote.contains('"') && unquote != trimmed)) //spaces mean options, if not everything is quoted
 		                   && (QFileInfo(unquote).exists())		      
 		                   )
-		               ))
+                       )){
 			commandLine = cmdString + " " + defaultArgs;
-		else
+        } else {
 			commandLine = cmdString;
+        }
 	}
 }
 
@@ -129,7 +130,35 @@ QString BuildManager::chainCommands(const QString& a, const QString& b) { return
 QString BuildManager::chainCommands(const QString& a, const QString& b, const QString& c) { return a + "|" + b + "|" + c; }
 QString BuildManager::chainCommands(const QString& a, const QString& b, const QString& c, const QString& d)  { return a + "|" + b + "|" + c + "|" + d;  }
 
-
+/** splits a string into options. Splitting occurs at spaces, except in quotes. **/
+QStringList BuildManager::splitOptions(const QString &s)
+{
+	QStringList options;
+	QChar c;
+	bool inQuote = false;
+	int start = 0;
+	int i;
+	for (i=0; i<s.length(); i++) {
+		c = s[i];
+		if (inQuote) {
+			if (c == '"' && s[i-1]!='\\') {
+				inQuote = false;
+			}
+		} else {
+			if (c == '"') {
+				inQuote = true;
+			} else if (c == ' ') {
+				if (start == i) start = i+1; // multiple spaces;
+				else {
+					options << dequoteStr(s.mid(start, i-start));
+					start = i+1;
+				}
+			}
+		}
+	}
+	if (start < i) options << dequoteStr(s.mid(start, i-start));
+	return options;
+}
 
 BuildManager::BuildManager(): processWaitedFor(0)
      #ifdef Q_OS_WIN32
@@ -177,7 +206,7 @@ void BuildManager::initDefaultCommandNames(){
 	registerCommand("asy",         "asy",          "Asymptote",   "?m*.asy", "Tools/Asy");
 	registerCommand("gs",          "gs;mgs",           "Ghostscript", "\"?am.ps\"", "Tools/Ghostscript", &getCommandLineGhostscript);
 	QStringList ltxmk_cmds;
-	ltxmk_cmds << "latexmk -pdf -silent -pdflatex=\"pdflatex -synctex=1 %%O %%S\" %" << "latexmk -dvi -silent -latex=\"latex -src %%O %%S\" %";
+	ltxmk_cmds << "latexmk -pdf -silent -latexoption=\"-synctex=1\" %" << "latexmk -dvi -silent %";
 	registerCommand("latexmk",     "Latexmk", ltxmk_cmds,"",false);
 	
 	
@@ -612,6 +641,10 @@ ExpandedCommands BuildManager::expandCommandLine(const QString& str, ExpandingOp
 			if (cmd.isEmpty()) { 
 				if (options.nestingDeep == 1) txsWarning(tr("Command %1 not defined").arg(subcmd)); 
 				else if (cmdName != "pre-compile") qDebug() << tr("Command %1 not defined").arg(subcmd); //pre-compile is expecte
+                if(cmdName != "pre-compile"){
+                    res.commands<<CommandToRun(""); // add empty command to provoke an error on higher level. Otherwise the missing of the command is simply ignoed e.g. txs:/quick without empty pdflatex
+                    res.primaryCommand="";
+                }
 				continue; 
 			}
 			
@@ -1050,7 +1083,30 @@ bool BuildManager::runCommand(const QString &unparsedCommandLine, const QFileInf
 	ExpandingOptions options(mainFile, currentFile, currentLine);
 	ExpandedCommands expansion = expandCommandLine(unparsedCommandLine, options);
 	if (options.canceled) return false;
-	if (expansion.commands.isEmpty()) return true;
+    if (expansion.commands.isEmpty()) {
+        emit processNotification(tr("Error: No command expanded"));
+        if (!BuildManager_hadSuccessfulProcessStart){
+            emit processNotification("<br>" + tr("<b>Make sure that you have installed a (La)TeX distribution</b> e.g. MiKTeX or TeX Live, and have set the correct paths to this distribution on the command configuration page.<br>"
+                                        "A (La)TeX editor like TeXstudio cannot work without the (La)TeX commands provided by such a distribution."));
+        }
+
+        return false;
+    }
+    // check if one command in the list is empty (expansion produced an error, e.g. txs:quick and compile is undefined
+    bool emptyCommand=false;
+    foreach(const CommandToRun elem,expansion.commands) {
+        if(elem.command.isEmpty())
+            emptyCommand=true;
+    }
+    if (emptyCommand) {
+        emit processNotification(tr("Error: One command expansion invalid."));
+        if (!BuildManager_hadSuccessfulProcessStart){
+            emit processNotification("<br>" + tr("<b>Make sure that you have installed a (La)TeX distribution</b> e.g. MiKTeX or TeX Live, and have set the correct paths to this distribution on the command configuration page.<br>"
+                                        "A (La)TeX editor like TeXstudio cannot work without the (La)TeX commands provided by such a distribution."));
+        }
+
+        return false;
+    }
 	
 	bool latexCompiled = false, pdfChanged = false;
 	for (int i=0;i<expansion.commands.size();i++){
@@ -1568,28 +1624,28 @@ bool BuildManager::testAndRunInternalCommand(const QString& cmd, const QFileInfo
 	return false;
 }
 
-QString BuildManager::findFile(const QString& defaultName, const QString& searchPaths){
+QString BuildManager::findFile(const QString& defaultName, const QStringList& searchPaths){
 	//TODO: merge with findResourceFile
 	QFileInfo base(defaultName);
 	if (base.exists()) return defaultName;
 	if (searchPaths.isEmpty()) return "";
 	
-	QString absPath = base.absolutePath() + "/";
-	QString baseName = "/" + base.fileName();
-	              
-	
-#ifdef Q_OS_WIN32
-	QString dirSep = ";";
-#else
-	QString dirSep = ":";
-#endif
-	QStringList paths = searchPaths.split(dirSep);
-	
-	foreach (const QString& p, paths)
-		if (p.startsWith('/') || p.startsWith("\\\\") || (p.length() > 2 && p[1] == ':' && p[2] == '\\')) {
-			if (QFileInfo(p + baseName).exists()) return p + baseName;
-		} else 
-			if (QFileInfo(absPath + p + baseName).exists()) return absPath + p + baseName;
+	foreach (QString p, searchPaths) {
+		if (p.startsWith('/') || p.startsWith("\\\\") || (p.length() > 2 && p[1] == ':' && (p[2] == '\\' || p[2] == '/'))) {
+			QFileInfo fi(QDir(p), base.fileName());
+			if (fi.exists()) return fi.absoluteFilePath();
+		} else {
+			// ?? seems a bit weird: if p is not an absolute path, then interpret p as directory
+			// e.g. default = /my/filename.tex
+			//      p = foo
+			// -->  /my/foo/filename.tex
+			// TODO: do we want/use this anywere or can it be removed?
+			QString absPath = base.absolutePath() + "/";
+			QString baseName = "/" + base.fileName();
+			QFileInfo fi(absPath + p + baseName);
+			if (fi.exists()) return fi.absoluteFilePath();
+		}
+	}
 	return "";
 }
 
@@ -1746,6 +1802,9 @@ void ProcessX::startCommand() {
 	QProcess::start(cmd);
 	qputenv("PATH", path); // restore
 
+    if (error() == FailedToStart || error() == Crashed)
+        isStarted = ended = true; //prevent call of waitForStarted, if it failed to start (see QTBUG-33021)
+
 #ifdef PROFILE_PROCESSES
 	connect(this, SIGNAL(finished(int)), SLOT(finished()));
 	time.start();
