@@ -117,6 +117,7 @@ public:
 	static QString chainCommands(const QString& a, const QString& b, const QString& c);
 	static QString chainCommands(const QString& a, const QString& b, const QString& c, const QString& d);
 	
+	static QStringList splitOptions(const QString &s);
 	static QString findFileInPath(QString fileName);
 	static QStringList parseExtendedCommandLine(QString str, const QFileInfo &mainFile, const QFileInfo &currentFile = QFileInfo(), int currentLine=0);
 	ExpandedCommands expandCommandLine(const QString& str, ExpandingOptions& expandingOptions);
@@ -210,7 +211,7 @@ public:
 	static QString autoRerunCommands;
 	static QString additionalSearchPaths, additionalLogPaths, additionalPdfPaths;
 	
-	QString findFile(const QString& baseName, const QString& searchPaths);
+	QString findFile(const QString& baseName, const QStringList& searchPaths);
     void addPreviewFileName(QString fn){
         if(!previewFileNames.contains(fn))
             previewFileNames.append(fn);
