@@ -32,26 +32,26 @@ ShortcutComboBox::ShortcutComboBox(QWidget *parent):QComboBox(parent){
 	addItem(tr("<default>"));
 	addItem(tr("<none>"));
 	for (int k=Qt::Key_F1; k<=Qt::Key_F12; k++)
-		addItem(QKeySequence(k).toString(QKeySequence::NativeText));
+		addItem(QKeySequence(k).toString(SHORTCUT_FORMAT));
 	for (int m=0; m<=1; m++)
 		for (int c=0; c<=1; c++)
 			for (int s=0; s<=1; s++)
 				for (int a=0; a<=1; a++) {
 					if (a || c || s || m) {
 						for (int k=Qt::Key_F1; k<=Qt::Key_F12; k++)
-							addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(QKeySequence::NativeText));
+							addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(SHORTCUT_FORMAT));
 						for (int k=Qt::Key_0; k<=Qt::Key_9; k++)
-							addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(QKeySequence::NativeText));
+							addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(SHORTCUT_FORMAT));
 						for (int k=Qt::Key_A; k<=Qt::Key_Z; k++)
-							addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(QKeySequence::NativeText));
+							addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(SHORTCUT_FORMAT));
 						if (a || c) {
 							for (int k=Qt::Key_Left; k<=Qt::Key_Down; k++)
-								addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(QKeySequence::NativeText));
+								addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(SHORTCUT_FORMAT));
 							for (int k=Qt::Key_PageUp; k<=Qt::Key_PageDown; k++)
-								addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(QKeySequence::NativeText));
+								addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+k).toString(SHORTCUT_FORMAT));
 						}
 					}
-					addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+Qt::Key_Tab).toString(QKeySequence::NativeText));
+					addItem(QKeySequence(c*Qt::CTRL+s*Qt::SHIFT+a*Qt::ALT+m*Qt::META+Qt::Key_Tab).toString(SHORTCUT_FORMAT));
 				}
 	setEditable(true);
 }
@@ -70,7 +70,7 @@ void ShortcutComboBox::keyPressEvent(QKeyEvent *e){
 		// FIXME: Qt currently does not handle KeypadModifier correctly.
 		// as a workaround we just take it away, so there is no difference between keypad and non-keypad keys,
 		// but at least keypad keys don't produce rubbish. See also sf.net bug item 3525266
-		QString newShortCut = QKeySequence((e->modifiers() | e->key()) & ~Qt::KeypadModifier).toString(QKeySequence::NativeText);
+		QString newShortCut = QKeySequence((e->modifiers() | e->key()) & ~Qt::KeypadModifier).toString(SHORTCUT_FORMAT);
 		int index = findText(newShortCut);
 		if (index != -1) setCurrentIndex(index);
 		else setEditText(newShortCut);
@@ -136,7 +136,7 @@ void ShortcutDelegate::setEditorData(QWidget *editor,
 	QString value = index.model()->data(index, Qt::EditRole).toString();
 	//menu shortcut key
 	if (box) {
-		QString normalized=QKeySequence(value).toString(QKeySequence::NativeText);
+		QString normalized=QKeySequence(value).toString(SHORTCUT_FORMAT);
 		int pos=box->findText(normalized);
 		if (pos==-1) box->setEditText(value);
 		else box->setCurrentIndex(pos);
@@ -177,7 +177,7 @@ void ShortcutDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 	if (value=="" || value=="none" || value==tr("<none>")) value="";
 	else if (value=="<default>") ;
 	else {
-		value=QKeySequence(box->currentText()).toString(QKeySequence::NativeText);
+		value=QKeySequence(box->currentText()).toString(SHORTCUT_FORMAT);
 		if (value=="" || (value.endsWith("+") && !value.endsWith("++"))) { //Alt+wrong=>Alt+
 			txsWarning(ConfigDialog::tr("The shortcut you entered is invalid."));
 			return;
@@ -209,11 +209,17 @@ void ShortcutDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 			QTreeWidgetItem* editorKeys = treeWidget->topLevelItem(1)->child(0);
 			REQUIRE(editorKeys);
 			if (!li.empty() && li.first()) {
-				QString duplicate=li.first()->text(0);//model->data(model->index(mil[0].row(),0,mil[0].parent()),Qt::DisplayRole).toString();
+				QStringList duplicates;
+				foreach (QTreeWidgetItem *twi, li) {
+					if (twi) duplicates << twi->text(0);
+				}
+				QString duplicate = duplicates.join("\n");
 				if (txsConfirmWarning(QString(ConfigDialog::tr("The shortcut <%1> is already assigned to the command:")).arg(value) +"\n"+duplicate+"\n\n"+ConfigDialog::tr("Do you wish to remove the old assignment and bind the shortcut to the new command?"))) {
 					//model->setData(mil[0],"",Qt::DisplayRole);
-					if (li[0]->text(2) == value)  li[0]->setText(2,"");
-					else if (li[0]->text(3) == value)  li[0]->setText(3,"");
+					foreach (QTreeWidgetItem *twi, li) {
+						if (twi and twi->text(2) == value) twi->setText(2, "");
+						else if (twi and twi->text(2) == value) twi->setText(2, "");
+					}
 				} else {
 					return;
 				}
@@ -352,13 +358,16 @@ ConfigDialog::ConfigDialog(QWidget* parent): QDialog(parent), checkboxInternalPD
 	connect(ui.checkBoxShowOnlyMonospacedFonts, SIGNAL(toggled(bool)), this, SLOT(populateComboBoxFont(bool)));
 
 	ui.comboBoxEncoding->addItem("UTF-8");
+    ui.comboBoxBibFileEncoding->addItem("UTF-8");
 	foreach(int mib, QTextCodec::availableMibs()) {
 		QTextCodec *codec = QTextCodec::codecForMib(mib);
 		if (!codec) continue;
-		if (codec->name()!="UTF-8") ui.comboBoxEncoding->addItem(codec->name());
+        if (codec->name()!="UTF-8") {
+            ui.comboBoxEncoding->addItem(codec->name());
+            ui.comboBoxBibFileEncoding->addItem(codec->name());
+        }
 	}
 
-
 	ui.comboBoxThesaurusFileName->setCompleter(0);
 
 	connect(ui.pushButtonDictDir, SIGNAL(clicked()), this, SLOT(browseDictDir()));
@@ -421,6 +430,7 @@ ConfigDialog::ConfigDialog(QWidget* parent): QDialog(parent), checkboxInternalPD
     createIcon(tr("Shortcuts"),getRealIcon("config_shortcut"));
     createIcon(tr("Menus"),getRealIcon("config_latexmenus"), true);
     createIcon(tr("Toolbars"),getRealIcon("config_toolbars"), true);
+    createIcon(tr("GUI Scaling"),getRealIcon("config_toolbars"), true);
     createIcon(tr("Editor"),getRealIcon("config_editor"));
     createIcon(tr("Adv. Editor"),getRealIcon("config_advancededitor"), true);
     createIcon(tr("Syntax Highlighting"),getRealIcon("config_highlighting"));
@@ -463,17 +473,6 @@ ConfigDialog::ConfigDialog(QWidget* parent): QDialog(parent), checkboxInternalPD
 	ui.checkBoxUseSystemTheme->setVisible(false);
 #endif
 	
-	QRect screen = QApplication::desktop()->screenGeometry();
-	if (!screen.isEmpty()) {
-		int nwidth = width(), nheight = height();
-		if (nwidth > screen.width()) nwidth = screen.width();
-		if (nheight > screen.height()) nheight = screen.height();
-		if (nwidth == width() && nheight == height()) return;
-		resize(nwidth, nheight);
-		move(frameGeometry().right() > screen.right()?screen.left():x(),
-		     frameGeometry().bottom() > screen.bottom()?screen.left():y());
-	}
-
 #if QT_VERSION < 0x040800
 	ui.checkBoxVisualColumnMode->setChecked(false);
 	ui.checkBoxVisualColumnMode->setEnabled(false);
@@ -487,6 +486,24 @@ ConfigDialog::ConfigDialog(QWidget* parent): QDialog(parent), checkboxInternalPD
     ui.comboBoxPreviewMode->removeItem(l-1);
     // maybe add some possibility to disable some preview modes in poppler mode
 #endif
+
+    // set-up GUI scaling
+    connect(ui.tbRevertIcon,SIGNAL(clicked()),this,SLOT(revertClicked()));
+    connect(ui.tbRevertCentralIcon,SIGNAL(clicked()),this,SLOT(revertClicked()));
+    connect(ui.tbRevertSymbol,SIGNAL(clicked()),this,SLOT(revertClicked()));
+
+    // limit dialog size
+    QRect screen = QApplication::desktop()->screenGeometry();
+    if (!screen.isEmpty()) {
+        int nwidth = width(), nheight = height();
+        if (nwidth > screen.width()) nwidth = screen.width();
+        if (nheight > screen.height()) nheight = screen.height();
+        if (nwidth == width() && nheight == height()) return;
+        resize(nwidth, nheight);
+        move(frameGeometry().right() > screen.right()?screen.left():x(),
+             frameGeometry().bottom() > screen.bottom()?screen.left():y());
+    }
+
 }
 
 ConfigDialog::~ConfigDialog() {
@@ -514,6 +531,20 @@ void ConfigDialog::changePage(QListWidgetItem *current, QListWidgetItem *previou
 	ui.pagesWidget->setCurrentIndex(lastUsedPage);
 }
 
+void ConfigDialog::revertClicked(){
+    QToolButton *bt=qobject_cast<QToolButton*>(sender());
+    if(bt){
+        if(bt->objectName()=="tbRevertIcon"){
+            ui.horizontalSliderIcon->setValue(22);
+        }
+        if(bt->objectName()=="tbRevertCentralIcon"){
+            ui.horizontalSliderCentraIcon->setValue(16);
+        }
+        if(bt->objectName()=="tbRevertSymbol"){
+            ui.horizontalSliderSymbol->setValue(32);
+        }
+    }
+}
 
 //sets the items of a combobox to the filenames and sub-directory names in the directory which name
 //is the current text of the combobox
@@ -629,6 +660,8 @@ void ConfigDialog::hideShowAdvancedOptions(QWidget* w, bool on){
 		if (!w) continue;
 		if (w->property("advancedOption").isValid() && w->property("advancedOption").toBool())
 			w->setVisible(on);
+        if (w->property("hideWidget").isValid() && w->property("hideWidget").toBool())
+            w->hide();
         // special treatment for metacommads
         static QStringList simpleMetaOptions = QStringList() << "quick" << "compile" << "view" << "view-pdf" << "bibliography";
         if(simpleMetaOptions.contains(w->objectName())){
@@ -778,8 +811,10 @@ void ConfigDialog::loadOtherIcon(){
 		return;
 	}
     QString fn = QFileDialog::getOpenFileName(this,tr("Select a File"),"",tr("Images") + " (*.png *.xpm *.jpg *.jpeg *.bmp *.svg)");
+
 	if(!fn.isEmpty()){
 		item->setIcon(QIcon(fn));
+		fn = ConfigManager::getInstance()->reverseParseDir(fn);
 		replacedIconsOnMenus->insert(item->data(Qt::UserRole).toString(),fn);
 		ui.listCustomToolBar->reset();
 		// set the same icon on other list
@@ -966,3 +1001,4 @@ bool ConfigDialog::askRiddle(){
 	*/
 }
 
+
