@@ -15,6 +15,12 @@ class InsertGraphicsConfig;
 struct PDFDocumentConfig;
 class GrammarCheckerConfig;
 
+#ifdef Q_OS_WIN
+	const QKeySequence::SequenceFormat SHORTCUT_FORMAT = QKeySequence::PortableText;
+#else
+	const QKeySequence::SequenceFormat SHORTCUT_FORMAT = QKeySequence::NativeText;
+#endif
+
 struct ManagedToolBar{
 	QString name;
 	QStringList defaults;
@@ -62,7 +68,7 @@ public:
 	QPalette systemPalette; 
 	QString interfaceStyle;
 	QString interfaceFontFamily;
-	int guiToolbarIconSize;
+    int guiToolbarIconSize,guiSymbolSize;
 	int guiSecondaryToolbarIconSize;
 	bool useTexmakerPalette;
 	int interfaceFontSize;
@@ -73,6 +79,9 @@ public:
 	bool showLineNumbersInStructure;
 	int indentationInStructure;
 	bool indentIncludesInStructure;
+	bool showCommentedElementsInStructure;
+	bool markStructureElementsBeyondEnd;
+	bool markStructureElementsInAppendix;
 	QString referenceCommandsInContextMenu;
 	
 	//update
@@ -138,6 +147,7 @@ public:
 	bool rememberFileFilter;
 	bool sessionRestore;
 	bool parseBibTeX, parseMaster;
+    QString bibFileEncoding;
     bool autoLoadChildren;
 
         //autosave
@@ -227,6 +237,9 @@ public:
 signals:
 	void newLeftPanelLayoutChanged(bool newValue);
 	void watchedMenuChanged(const QString& menuId);
+    void iconSizeChanged(int value);
+    void centralIconSizeChanged(int value);
+    void symbolSizeChanged(int value);
 public:
 //private:
 	QString configFileName,configFileNameBase,defaultStyleName,configBaseDir;
