@@ -7,7 +7,7 @@ GrammarError::GrammarError(int offset, int length, const GrammarErrorType& error
 GrammarError::GrammarError(int offset, int length, const GrammarError& other):offset(offset),length(length),error(other.error),message(other.message),corrections(other.corrections){}
 
 GrammarCheck::GrammarCheck(QObject *parent) :
-QObject(parent), backend(0), ticket(0)
+	QObject(parent), backend(0), ticket(0), pendingProcessing(false)
 {
 	latexParser = new LatexParser();
 }
@@ -86,7 +86,19 @@ void GrammarCheck::check(const QString& language, const void * doc, const QList<
 	requests << CheckRequest(lang,doc,inlines,firstLineNr,ticket);
 
 	//Delay processing, because there might be more requests for the same line in the event queue and only the last one needs to be checked
-	QTimer::singleShot(50, this, SLOT(process()));
+	if (!pendingProcessing) {
+		pendingProcessing = true;
+		QTimer::singleShot(50, this, SLOT(processLoop()));
+	}
+}
+
+void GrammarCheck::processLoop() {
+	for (int i=requests.size()-1;i>=0;i--)
+		if (requests[i].pending) {
+			requests[i].pending = false;
+			process(i);
+		}
+	pendingProcessing = false;
 }
 
 const QString uselessPunctation = "!:?,.;-"; //useful: \"(
@@ -98,18 +110,9 @@ const QString noSpacePunctation = "!:?,.;)";
   if ((words)[i-1].length() == 1 && ((words)[i-1] == "(" || (words)[i-1] == "\"")) continue; \
   if ((words)[i-1].length() == 2 && (words)[i-1][1] == '.' && (words)[i].length() == 2 && (words)[i][1] == '.') continue; /* abbeviations like "e.g." */ \
 
-void GrammarCheck::process(){
+void GrammarCheck::process(int reqId){
 	REQUIRE(latexParser);
 	REQUIRE(!requests.isEmpty());
-		
-	int reqId = -1;
-	for (int i=requests.size()-1;i>=0;i--)
-		if (requests[i].pending) {
-			reqId = i;
-			requests[i].pending = false;
-			break;
-		}
-	REQUIRE(reqId != -1);
 	
 	CheckRequest &cr = requests[reqId];
 	
@@ -221,6 +224,17 @@ void GrammarCheck::process(){
 	}
 	while (blocks.size()) cr.blocks << blocks.takeLast();
 	
+
+	for (int b = 0; b < cr.blocks.size(); b++) {
+		TokenizedBlock &tb = cr.blocks[b];
+		while (!tb.words.isEmpty() && tb.words.first().length() == 1 && uselessPunctation.contains(tb.words.first()[0])) {
+			tb.words.removeFirst();
+			tb.indices.removeFirst();
+			tb.endindices.removeFirst();
+			tb.lines.removeFirst();
+		}
+	}
+
 	bool backendAvailable = backend->isAvailable();
 
 	QList<TokenizedBlock> crBlocks = cr.blocks; //cr itself might become invalid during the following loop
@@ -228,18 +242,11 @@ void GrammarCheck::process(){
 	QString crLanguage = cr.language;
 
 	for (int b = 0; b < crBlocks.size(); b++) {
-		TokenizedBlock &tb = crBlocks[b];
-		while (!tb.words.isEmpty() && tb.words.first().length() == 1 && uselessPunctation.contains(tb.words.first()[0])) {
-			tb.words.removeFirst();
-			tb.indices.removeFirst();
-			tb.endindices.removeFirst();
-			tb.lines.removeFirst();
-		}
-
+		const TokenizedBlock &tb = crBlocks.at(b);
 		if (tb.words.isEmpty() || !backendAvailable) backendChecked(crTicket, b, QList<GrammarError>(), true);
 		else  {
 			QString joined;
-			QStringList & words = tb.words;
+			const QStringList & words = tb.words;
 			int expectedLength = 0; foreach (const QString& s, words) expectedLength += s.length();
 			joined.reserve(expectedLength+words.length());
 			for (int i=0;;) {
