@@ -524,10 +524,10 @@ int QDocumentSearch::next(bool backward, bool all, bool again, bool allowWrapAro
 	
 	int foundCount = 0;
 
-    if (m_editor && all && !hasOption(Prompt)){
-        m_editor->document()->beginMacro();
+	if (m_editor && hasOption(Replace) && all && !hasOption(Prompt)){
+		m_editor->document()->beginMacro();
 		m_editor->document()->beginDelayedUpdateBlock();
-    }
+	}
 	
 	m_cursor.setColumnMemory(false);
 	QDocumentCursor lastSelection;
@@ -639,14 +639,12 @@ int QDocumentSearch::next(bool backward, bool all, bool again, bool allowWrapAro
 	}
 	if ( all && replaceCount )
 		updateReplacementOverlays();
-	if ( m_editor && all ) {
-		if (!hasOption(Prompt)) {
-			m_editor->document()->endDelayedUpdateBlock();
-            m_editor->document()->endMacro();
-			if (!hasOption(Silent)){
-				m_editor->setCursor(lastSelection, false);
-				m_editor->ensureCursorVisible(QEditor::Navigation);
-			}
+	if ( m_editor && hasOption(Replace) && all && !hasOption(Prompt)) {
+		m_editor->document()->endDelayedUpdateBlock();
+		m_editor->document()->endMacro();
+		if (!hasOption(Silent)){
+			m_editor->setCursor(lastSelection, false);
+			m_editor->ensureCursorVisible(QEditor::Navigation);
 		}
 	}
 		
