@@ -588,13 +588,13 @@ bool findTokenWithArg(const QString &line,const QString &token, QString &outName
  *
  * Returns the starting position of cmd in line, or -1 if no command was found.
  */
-int findCommandWithArgs(const QString &line, QString &cmd, QStringList &args, QList<int> *argStarts, int offset) {
+int findCommandWithArgs(const QString &line, QString &cmd, QStringList &args, QList<int> *argStarts, int offset, bool parseComment) {
 	// true means that a command is found, with or without arguments ...
 	// otherwise a command before the interesting command leads to quiting the loop
 	static QRegExp rxCmd("\\\\\\w+\\*?");
 	static QRegExp rxComment("(^|[^\\\\])%");
 	int cmdStart = rxCmd.indexIn(line, offset);
-	int commentStart = rxComment.indexIn(line);
+	int commentStart = parseComment ? -1 : rxComment.indexIn(line);
 	if (cmdStart==-1 || (commentStart >= 0 && commentStart < cmdStart)) {
         return -1;  // no command found
 	}
@@ -1566,11 +1566,11 @@ int LatexParser::lineEnd(const QByteArray& data, int index) {
 	else if (r<0) r=n;
 	n = qMin(n, r);
 
-	r = data.indexOf("\x20\x29",index);
+	r = data.indexOf("\x20\x29",index);  // unicode paragraph separator, note this is equivalent to " )" in ASCII but this duplication is ok for the current usecase of lineEnd()
 	if (n<0) n=r;
 	else if (r<0) r=n;
 	n = qMin(n, r);
-	if (n >= 0) return r;
+	if (n >= 0) return n;
 	return data.size();
 }
 
@@ -2229,7 +2229,7 @@ QString getImageAsText(const QPixmap &AImage,const int w) {
 
 void showTooltipLimited(QPoint tt,QString topic,int width){
     topic.replace("\t","    "); //if there are tabs at the position in the string, qt crashes. (13707)
-    QRect screen = QApplication::desktop()->availableGeometry();
+    QRect screen = QApplication::desktop()->availableGeometry(tt);
     // estimate width of coming tooltip
     // rather dirty code
     QLabel lLabel(0,Qt::ToolTip);
@@ -2238,24 +2238,26 @@ void showTooltipLimited(QPoint tt,QString topic,int width){
     lLabel.setFrameStyle(QFrame::StyledPanel);
     lLabel.setAlignment(Qt::AlignLeft);
     lLabel.setIndent(1);
-    //lLabel.setWordWrap(true);
+    lLabel.setWordWrap(true);
     //lLabel.ensurePolished();
     lLabel.setText(topic);
     lLabel.adjustSize();
 
     int textWidthInPixels = lLabel.width()+10; // +10 good guess
 
-    if (screen.width()-textWidthInPixels>=tt.x()) {
-        QToolTip::showText(tt, topic);//-90
+    if (tt.x() - screen.x() + textWidthInPixels <= screen.width()) {
+        // tooltip fits at the requested position
+        QToolTip::showText(tt, topic);
     } else {
-        //list->mapToGlobal
-        QPoint tt2(tt.x()-textWidthInPixels-width, tt.y());
-
+        QPoint tt2(tt.x() - textWidthInPixels - width, tt.y());
         // check if text left from list would fit
         bool reCalc=false;
-        if(tt2.x()<0){
-            //determine max usable width
-            int w=tt.x()-width;
+        if(tt2.x()<screen.x()){
+            // text does not fit to the left
+            // determine max usable width to the left
+            // TODO: the code in this block does not account for multiple screens
+            //       we have to subtract screen.x() from tt.x() in various places
+            int w=tt.x()-width; // widthToTheLeft
             if(screen.width()-tt.x()>w){
                 w=screen.width()-tt.x();
                 tt2=tt;
@@ -2319,3 +2321,4 @@ bool addMostRecent(const QString & item, QStringList & mostRecentList, int maxLe
 	if (mostRecentList.count() > maxLength) mostRecentList.removeLast();
 	return changed;
 }
+
