@@ -15,6 +15,11 @@ QString TemplateManager::builtinTemplateDir()
 {
 #ifdef Q_OS_MAC
 	QString fn = "/Applications/texstudio.app/Contents/Resources/";
+    if(!QDir(fn).isReadable()) { // fallback if program is not installed
+        fn=QCoreApplication::applicationDirPath();
+        fn.chop(6);
+        fn+="/Resources/";
+    }
 	if(!QDir(fn).isReadable()) { // fallback if program is not packaged as app (e.g. debug build )
 		return QCoreApplication::applicationDirPath()+"/templates/";
 	}
