@@ -83,7 +83,7 @@ public:
 	bool tobemaximized,tobefullscreen;
 
 public slots:
-    LatexEditorView* load(const QString &f , bool asProject = false, bool hidden = false, bool recheck=true);
+    LatexEditorView* load(const QString &f , bool asProject = false, bool hidden = false, bool recheck=true,bool dontAsk=false);
 	void executeCommandLine(const QStringList& args, bool realCmdLine);
 	void startupCompleted();
 	void onOtherInstanceMessage(const QString &);  // For messages for the single instance
@@ -122,7 +122,8 @@ private:
 	void setupToolBars();
 	void createStatusBar();
 	bool ActivateEditorForFile(QString f, bool checkTemporaryNames = false, bool setFocus = true);
-	bool closeAllFilesAsking(); //asks the user and close all files
+	bool saveAllFilesForClosing(); // checks for unsaved files and asks the user if they should be saved
+	void closeAllFiles();
 	bool canCloseNow(); //asks the user and close all files, and prepares to exit txs
 	void closeEvent(QCloseEvent *e);
 	
@@ -261,6 +262,7 @@ private slots:
 	void fileCheckinPdf(QString filename="");
 	void fileUpdate(QString filename="");
 	void fileUpdateCWD(QString filename="");
+	void checkinAfterSave(QString filename);
 	void checkin(QString fn,QString text="txs auto checkin",bool blocking=false);
 	bool svnadd(QString fn,int stage=0);
 	void svncreateRep(QString fn);
@@ -335,6 +337,8 @@ protected slots:
 	void structureContextMenuSwitchMasterDocument();
 	void structureContextMenuExpandSubitems();
 	void structureContextMenuCollapseSubitems();
+	void structureContextMenuExpandAllDocuments();
+	void structureContextMenuCollapseAllDocuments();
 	void SymbolGridContextMenu(QWidget* widget, const QPoint& point);
 	void MostUsedSymbolsTriggered(bool direct=false);
 	void symbolAddFavorite();
@@ -362,6 +366,8 @@ protected slots:
 	void EditorTabMoved(int from,int to);
 	void editorAboutToChangeByTabClick(LatexEditorView *edFrom, LatexEditorView *edTo);
 
+	void getExpandedStructureEntries(const QModelIndex & index, QSet<QString> & expandedEntryTags, QString baseTag = QString());
+	void expandStructureEntries(const QModelIndex index, const QSet<QString> & expandedEntryTags, QString baseTag = QString());
     void updateStructure(bool initial=false, LatexDocument *doc = 0, bool hidden=false);
 	void ShowStructure();
 	void clickedOnStructureEntry(const QModelIndex & index);
@@ -404,6 +410,7 @@ protected slots:
 	void EditorSpellerChanged(const QString &name);
 	void ChangeEditorSpeller();
 	void InsertSpellcheckMagicComment();
+	void updateStatusBarEncoding();
     void addMagicRoot();
     void addMagicCoding();
 	
@@ -422,6 +429,10 @@ protected slots:
 
     void searchExtendToggled(bool toggled);
 
+    void changeIconSize(int value);
+    void changeCentralIconSize(int value);
+    void changeSymbolSize(int value, bool changePanel=true);
+
 public slots:
 	void connectSubCommand(ProcessX* p, bool showStdoutLocallyDefault);
 private slots:	
