@@ -18,6 +18,7 @@ extern const char* TEXSTUDIO_HG_REVISION;
 bool getDiskFreeSpace(const QString &path, quint64 &freeBytes);
 
 QChar getPathListSeparator();
+QStringList splitPaths(const QString &paths);
 
 QString getUserName();
 
@@ -48,6 +49,8 @@ QString getRelativeBaseNameToPath(const QString & file, QString basepath, bool b
 QString getPathfromFilename(const QString &compFile);
 QString findAbsoluteFilePath(const QString & relName, const QString &extension, const QStringList &searchPaths, const QString& fallbackPath);
 
+QString getEnvironmentPath();
+QStringList getEnvironmentPathList();
 void updatePathSettings(QProcess* proc, QString additionalPaths);
 
 //returns kde version 0,3,4
